package WWW::Shorten::Qurl;

use 5.006;
use strict;
use warnings;

our $VERSION = '2.012';
$VERSION = eval $VERSION;

require WWW::Shorten::_dead;

0;

=head1 NAME

WWW::Shorten::Qurl - Shorten URLs

=head1 SYNOPSIS

  # no viable use case

=head1 DESCRIPTION

This module is deprecated since the service no longer functions.  Please
see L<WWW::Shorten> instead.

=head1 AUTHOR

Dave Cross C<davecross@cpan.org>

=head1 CONTRIBUTORS

=over

=item *

Chase Whitener C<capoeirab@cpan.org>

=back

=head1 COPYRIGHT AND LICENSE

Under the terms and copyright of L<WWW::Shorten>

=head1 SEE ALSO

L<WWW::Shorten>

=cut
